import { scaleOrdinal } from 'd3';

// variables

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['red', 'yellow']);

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([50, 30]);


// functions


const xPosition = (d, i) => i * 120 + 60;



// (render)
export const fruitBowl = (selection, props ) => {
  const { fruits, height,setSelectedFruit,
        selectedFruit
        } = props;
  // represent data join as a variable
  const circles = selection.selectAll('circle')
  .data(fruits, d => d.id);
  
	// General update pattern:
  circles
    .enter().append('circle')
  // enter only effects data when it is initially bound
		.attr('cx', xPosition)
		.attr('cy', height / 2)
  	.attr('r', 0)
  .merge(circles) // merge == enter and update
		.attr('fill', (d) => colorScale(d.type))
  	.attr('stroke-width',5)
  	.attr('stroke',d=>
          d.id===selectedFruit
          ?'black'
          :'none'
          )
  	.on('mouseover',d=>setSelectedFruit(d.id))
  	.on('mouseout',d=>setSelectedFruit(null))
  // transition effects attr after it
  .transition().duration(1000)
		.attr('r', (d) => radiusScale(d.type))
  	.attr('cx', xPosition);
  
	// rebind data to new fruits array, then select
	// all circles that don't have data bound to them
	// (last apple no longer has data)
	circles.exit()
  	.transition().duration(1000)
  		.attr('r',0)
    .remove();  
}

